@@ -72,15 +72,6 @@
 #'      main = "Phyllomedusa species richness")
 #' # Map of the specific species      
 #' plot(PAM, name = "Phyllomedusa nordestina")
-#' 
-#' # Other projections
-#'  pro <- paste("+proj=eqdc +lat_0=-32 +lon_0=-60 +lat_1=-5",
-#'               "+lat_2=-42 +x_0=0 +y_0=0 +ellps=aust_SA", 
-#'               "+units=m +no_defs")
-#' SA_EC <- CRS(pro)
-#' PAM_proj <- lets.presab(shapes = Phyllomedusa, xmn = -4135157,
-#'                         xmx = 4707602, ymn = -450000, ymx = 5774733,
-#'                         resol = 100000, crs.grid = SA_EC)
 #'}
 
 
@@ -191,7 +182,7 @@ lets.presab <- function(shapes, xmn = -180, xmx = 180, ymn = -90,
                                  (n - i))))
       
       # Getting species position in the matrix and set to 1
-      pospos2 <- .extractpos(ras, shapes@polygons[[i]], nomes, nomes2,
+      pospos2 <- .extractpos(ras, shapes[i, ], nomes, nomes2,
                              cover, areashape, areagrid, i)      
       matriz[pospos2$pos2[, 1], pospos2$pos] <- 1      
     }
@@ -204,7 +195,7 @@ lets.presab <- function(shapes, xmn = -180, xmx = 180, ymn = -90,
     # Loop start, running repetitions for the number of polygons (n) 
     for(i in 1:n){
       # Getting species position in the matrix and set to 1
-      pospos2 <- .extractpos(ras, shapes@polygons[[i]], nomes, nomes2,
+      pospos2 <- .extractpos(ras, shapes[i, ], nomes, nomes2,
                              cover, areashape, areagrid, i)      
       matriz[pospos2$pos2[, 1], pospos2$pos] <- 1            
     }
@@ -246,16 +237,30 @@ lets.presab <- function(shapes, xmn = -180, xmx = 180, ymn = -90,
                         areashape, areagrid, i) {
   
   # Try the extraction of cell occurrence positions
+  shapepol1 <- shapepol
   celulas <- try(celulas <- extract(ras, 
-                                    SpatialPolygons(list(shapepol)),
+                                    shapepol1,
                                     cellnumbers = TRUE,
                                     weights = TRUE,
-                                    small = TRUE), 
+                                    small = TRUE,
+                                    normalizeWeights = FALSE), 
                  silent=T)
-  
+  if (class(celulas) != "try-error") {
+    celulas2 <- extract(
+      ras,
+      shapepol1,
+      cellnumbers = TRUE,
+      weights = FALSE,
+      small = TRUE,
+      normalizeWeights = FALSE
+    )
+    keep_this <- celulas[[1]][, 1] %in% celulas2[[1]][, 1]
+    celulas[[1]] <- celulas[[1]][keep_this, ,drop = FALSE]
+  }
+
   # Handle the awkward error that can appear with weights and small = TRUE 
   if (class(celulas) == "try-error") {
-    celulas <- extract(ras, SpatialPolygons(list(shapepol)),
+    celulas <- extract(ras, shapepol1,
                        cellnumbers = TRUE)
     nen <- sapply(celulas, nrow)
     for (ky in 1:length(nen)) {
