@@ -3,6 +3,7 @@ context("Test for lets.correl")
 N <- 100
 x <- rnorm(nrow(PAM[[1]]))[1:N]
 y <- lets.distmat(PAM[[1]][1:N, 1:2])
+y2 <- lets.distmat(PAM[[1]][1:N, 1:2], asdist = F)
 z <- 10
 equidistant <- FALSE
 plot <- FALSE
@@ -10,36 +11,36 @@ plot <- FALSE
 test_that("lets.correl works fine", {
   correl <- lets.correl(x, y, z, equidistant, plot)
   
-  expect_true(class(correl) == "matrix")
+  expect_true(is.matrix(correl))
   expect_true(all(!is.na(correl)))
 })
 
 test_that("lets.correl works fine, equidistant = TRUE", {
   correl <- lets.correl(x, y, z, equidistant = TRUE, plot)
   
-  expect_true(class(correl) == "matrix")
+  expect_true(is.matrix(correl))
   expect_true(all(!is.na(correl)))
 })
 
 test_that("lets.correl works fine, plot = TRUE", {
   correl <- lets.correl(x, y, z, plot = TRUE)
   
-  expect_true(class(correl) == "matrix")
+  expect_true(is.matrix(correl))
   expect_true(all(!is.na(correl)))
 })
 
 
 test_that("lets.correl works fine, matrix", {
-  correl <- lets.correl(x, as.matrix(y), z, plot)
+  correl <- lets.correl(x, y2, z, plot)
   
-  expect_true(class(correl) == "matrix")
+  expect_true(is.matrix(correl))
   expect_true(all(!is.na(correl)))
 })
 
 test_that("lets.correl works fine, multiple", {
   correl <- lets.correl(cbind(x, sample(x)), y, z, plot)
   
-  expect_true(class(correl) == "matrix")
+  expect_true(is.matrix(correl))
   expect_true(all(!is.na(correl)))
 })
 
@@ -53,7 +54,7 @@ test_that("lets.correl gives error", {
 
 
 test_that("lets.correl gives error", {
-  y <- as.matrix(y)
-  y[1, 1] <- NA
-  expect_error(lets.correl(x, y, z, plot))
+  y2[1, 1] <- NA
+  expect_error(lets.correl(x, y2, z, plot))
 })
+
