@@ -8,7 +8,7 @@ test_that("lets.overlap works fine, Chesser&Zink", {
   
   resu_test <- lets.overlap(PAM, method = "Chesser&Zink")  
   
-  expect_equal(class(resu_test), "matrix")  
+  expect_equal(class(resu_test)[1], "matrix")  
   expect_true(all(dim(resu_test) == length(PAM[[3]])))
   expect_true(!any(is.na(resu_test)))
   
@@ -21,7 +21,7 @@ test_that("lets.overlap works fine, xy = FALSE", {
                             method = "Chesser&Zink",
                             xy = FALSE)  
   
-  expect_equal(class(resu_test), "matrix")  
+  expect_equal(class(resu_test)[1], "matrix")  
   expect_true(all(dim(resu_test) == length(PAM[[3]])))
   expect_true(!any(is.na(resu_test)))
 })
@@ -34,7 +34,7 @@ test_that("lets.overlap works fine, xy = TRUE", {
                             method = "Chesser&Zink",
                             xy = TRUE)  
   
-  expect_equal(class(resu_test), "matrix")  
+  expect_equal(class(resu_test)[1], "matrix")  
   expect_true(all(dim(resu_test) == length(PAM[[3]])))
   expect_true(!any(is.na(resu_test)))
 })
@@ -44,7 +44,7 @@ test_that("lets.overlap works fine, Cells", {
   
   resu_test <- lets.overlap(PAM, method = "Cells")  
   
-  expect_equal(class(resu_test), "matrix")  
+  expect_equal(class(resu_test)[1], "matrix")  
   expect_true(all(dim(resu_test) == length(PAM[[3]])))
   expect_true(!any(is.na(resu_test)))
 })
@@ -54,7 +54,7 @@ test_that("lets.overlap works fine, Proportional", {
   
   resu_test <- lets.overlap(PAM, method = "Proportional")  
   
-  expect_equal(class(resu_test), "matrix")  
+  expect_equal(class(resu_test)[1], "matrix")  
   expect_true(all(dim(resu_test) == length(PAM[[3]])))
   expect_true(!any(is.na(resu_test)))
 })
